@@ -1,20 +1,19 @@
 import pandas as pd
 import numpy as np
 import os, uuid
-from vulcan_athena.mirandareporting.setup import CONNECTION_STRING
-from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, __version__
-
-CONTAINER_NAME = "container-test-output"
+from vulcan_athena.mirandareporting.setup import CONNECTION_STRING, STORAGEACCOUNTNAME, STORAGEACCOUNTKEY
+from azure.storage.blob import BlockBlobService
 
 
 def blob_writer(myobj, mystring):
-    BLOB_NAME = "./" + mystring
+    WRITE_CONTAINERNAME = "tem-financialreporting-base-tables"
+    BLOBNAME = mystring
 
-    blob = BlobClient.from_connection_string(conn_str=CONNECTION_STRING, container_name=CONTAINER_NAME,
-                                             blob_name=BLOB_NAME)
+    df_csv = myobj.to_csv(encoding="utf-8")
 
-    with open(myobj, "rb") as data:
-        blob.upload_blob(data, overwrite=True)
+    blobService = BlockBlobService(account_name=STORAGEACCOUNTNAME, account_key=STORAGEACCOUNTKEY)
+
+    blobService.create_blob_from_text(WRITE_CONTAINERNAME, BLOBNAME, df_csv)
 
 
 def base_table(data, year, month, status=''):
