@@ -3,34 +3,29 @@ This file is for setting up the global variables used throughout the project
 Customized folder paths and details to be initialized here
 '''
 
-from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, __version__
+from azure.storage.blob import BlockBlobService
 
 import pandas as pd
 
 # Azure credentials
 CONNECTION_STRING = "DefaultEndpointsProtocol=https;AccountName=sttemfinancialreporting;AccountKey=ow3mO+jsdSuM7REmLnSupIOyz0mPfwayuy1lt+5UMNykhNgWKfshr6SMV9ttyVxIP9kApKwW716xRaH3GGh8Og=="
-CONTAINERNAME = "tem-db-tables"
+STORAGEACCOUNTNAME = "sttemfinancialreporting"
+STORAGEACCOUNTKEY = "ow3mO+jsdSuM7REmLnSupIOyz0mPfwayuy1lt+5UMNykhNgWKfshr6SMV9ttyVxIP9kApKwW716xRaH3GGh8Og=="
 
+def blob_reader(BLOBNAME, LOCALFILENAME):
 
-def blob_reader(BLOBNAME):
-    # Create the BlobServiceClient object which will be used to get blob context
-    blob_service_client = BlobServiceClient.from_connection_string(CONNECTION_STRING)
-    # Create a blob client using the local file name as the name for the blob
-    blob_client_w = blob_service_client.get_blob_client(container=CONTAINERNAME, blob=BLOBNAME)
+    READ_CONTAINERNAME = "tem-db-tables"
 
-    local_file_name = './' + BLOBNAME
+    # download from blob
+    blob_service = BlockBlobService(account_name=STORAGEACCOUNTNAME, account_key=STORAGEACCOUNTKEY)
+    blob_service.get_blob_to_path(READ_CONTAINERNAME, BLOBNAME, LOCALFILENAME)
 
-    # download from blob and save it on local
-    with open(local_file_name, "wb") as download_file:
-        file = download_file.write(blob_client_w.download_blob().readall())
+    dataframe_blobdata = pd.read_csv(LOCALFILENAME)
 
-    # read it as csv and store in a dataframe
-    df = pd.read_csv(local_file_name)
-    return df
+    return dataframe_blobdata
 
-
-dataframe_ssp = blob_reader('ssp_table.csv')
-dataframe_tradebook = blob_reader('tradebook.csv')
+dataframe_ssp = blob_reader('ssp_table.csv', 'ssp_table.csv')
+dataframe_tradebook = blob_reader('tradebook.csv', 'tradebook.csv')
 
 dataframe_tradebook['Id'] = dataframe_tradebook['Id'].astype('int')
 dataframe_tradebook['TradeDate'] = pd.to_datetime(dataframe_tradebook['TradeDate'])
